%define upstream_name    Net-MAC-Vendor
%define upstream_version 1.265

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    Look up the vendor for a MAC
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        http://search.cpan.org/dist/%{upstream_name}
Source0:    ftp://ftp.perl.org/pub/CPAN/modules/by-module/Net/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Compress::Bzip2)
BuildRequires: perl(Compress::Zlib)
BuildRequires: perl(Cwd)
BuildRequires: perl(Data::Dumper)
BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(File::Temp)
BuildRequires: perl(Mojo::URL)
BuildRequires: perl(Mojo::UserAgent)
BuildRequires: perl(Net::SSLeay)
BuildRequires: perl(Test::More) >= 0.980.0
BuildRequires: perl(Text::ParseWords)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

%description
The Institute of Electrical and Electronics Engineers (IEEE) assigns an
Organizational Unique Identifier (OUI) to manufacturers of network
interfaces.  Each interface has a Media Access Control (MAC) address of six
bytes. The first three bytes are the OUI.

This module allows you to take a MAC address and turn it into the OUI and
vendor information.  You can, for instance, scan a network, collect MAC
addresses, and turn those addresses into vendors.  With vendor information,
you can often guess at what what you are looking at (e.g. an Apple product).

You can use this as a module as its individual functions, or call it as a
script with a list of MAC addresses as arguments. The module can figure it
out.  

This module tries to persistently cache with DBM::Deep the OUI information so
it can avoid using the network. If it cannot load DBM::Deep, it uses a normal
hash (which is lost when the process finishes). You can preload this cache
with the load_cache() function. So far, the module looks in the current
working directory for a file named mac_oui.db to find the cache. I need to
come up with a way to let the user set that location.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor
%make_build CFLAGS="%{optflags}"

%check
# Skip tests due to no networking on BS.
true || make test

%install
%make_install

%files
%doc CONTRIBUTING Changes INSTALL LICENSE META.json META.yml MYMETA.yml README examples
%{perl_vendorlib}/*
%{_mandir}/*/*


%changelog
* Sat Feb 15 2020 umeabot <umeabot> 1.265.0-2.mga8
+ Revision: 1525467
- Mageia 8 Mass Rebuild

* Wed Apr 17 2019 shlomif <shlomif> 1.265.0-1.mga7
+ Revision: 1392680
- skip tests
- update to 1.265
+ tv <tv>
- update to 1.263

* Thu Sep 20 2018 umeabot <umeabot> 1.262.0-3.mga7
+ Revision: 1285133
- Mageia 7 Mass Rebuild

* Tue Oct 03 2017 tv <tv> 1.262.0-2.mga7
+ Revision: 1165871
- rebuild with fixed rpm for missing autodeps

* Fri Sep 22 2017 guillomovitch <guillomovitch> 1.262.0-1.mga7
+ Revision: 1157243
- new version 1.262

* Sun Jun 19 2016 pterjan <pterjan> 1.260.0-2.mga6
+ Revision: 1031175
- Rebuild for perl 5.22.2

* Fri Apr 15 2016 shlomif <shlomif> 1.260.0-1.mga6
+ Revision: 1002259
- update to 1.26

* Fri Feb 19 2016 umeabot <umeabot> 1.250.0-2.mga6
+ Revision: 970018
- Mageia 6 Mass Rebuild

* Mon Sep 28 2015 sander85 <sander85> 1.250.0-1.mga6
+ Revision: 884745
- update to 1.25

* Tue Jun 23 2015 sander85 <sander85> 1.230.0-1.mga6
+ Revision: 840125
- update to 1.23

* Wed Oct 15 2014 umeabot <umeabot> 1.210.0-3.mga5
+ Revision: 750737
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.210.0-2.mga5
+ Revision: 685687
- Mageia 5 Mass Rebuild

* Sun Feb 09 2014 sander85 <sander85> 1.210.0-1.mga5
+ Revision: 587334
- update to 1.21

* Mon Oct 21 2013 umeabot <umeabot> 1.200.0-2.mga4
+ Revision: 539110
- Mageia 4 Mass Rebuild

* Fri Oct 04 2013 sander85 <sander85> 1.200.0-1.mga4
+ Revision: 491475
- update to 1.20

* Sun Jan 13 2013 umeabot <umeabot> 1.190.100-2.mga3
+ Revision: 370747
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 05 2012 kharec <kharec> 1.190.100-1.mga3
+ Revision: 288486
- update to 1.1901

* Thu Jan 20 2011 jquelin <jquelin> 1.180.0-1.mga1
+ Revision: 26710
- mageia rebuild
- imported package perl-Net-MAC-Vendor


* Wed Jul 29 2009 Jérôme Quelin <jquelin@mandriva.org> 1.180.0-1mdv2010.0
+ Revision: 404096
- rebuild using %%perl_convert_version

* Thu Jul 31 2008 Thierry Vignaud <tv@mandriva.org> 1.18-6mdv2009.0
+ Revision: 258055
- rebuild

* Thu Jul 24 2008 Thierry Vignaud <tv@mandriva.org> 1.18-5mdv2009.0
+ Revision: 246157
- rebuild

* Tue Jan 15 2008 Thierry Vignaud <tv@mandriva.org> 1.18-3mdv2008.1
+ Revision: 152222
- rebuild

* Tue Jan 15 2008 Thierry Vignaud <tv@mandriva.org> 1.18-2mdv2008.1
+ Revision: 152221
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Thu Nov 01 2007 Guillaume Rousse <guillomovitch@mandriva.org> 1.18-1mdv2008.1
+ Revision: 104563
- update to new version 1.18


* Tue Mar 13 2007 Oden Eriksson <oeriksson@mandriva.com> 1.17-1mdv2007.1
+ Revision: 143145
- Import perl-Net-MAC-Vendor

* Tue Mar 13 2007 Oden Eriksson <oeriksson@mandriva.com> 1.17-1mdv2007.1
- initial Mandriva package

